@@ -81,6 +81,7 @@ module CTioga2
         # * a transform is set
         # * ticks are set
 
+        @@text_size_index = 0
 
         # Creates a new AxisStyle object at the given location with
         # the given style.
@@ -90,10 +91,14 @@ module CTioga2
 
           @tick_label_style = FullTextStyle.new
           @tick_label_style.scale = Types::Dimension.new(:dy, 0.8)
+
           @axis_label = TextLabel.new(label)
           @log = false
           @ticks_side = {}
           @ticks = AxisTicks.new
+
+          @index = @@text_size_index
+          @@text_size_index += 1
         end
 
         # Draws the axis within the current plot. Boundaries are the
@@ -105,7 +110,9 @@ module CTioga2
         #   where it should be...
         # * non-linear axes (or linear, for that matter, but with
         #   a transformation)
-        def draw_axis(t)
+        #
+        # _watcher_ is a TextSizeWatcher object.
+        def draw_axis(t, watcher = nil)
           spec = get_axis_specification(t)
 
           info = t.axis_information(spec)
@@ -126,10 +133,76 @@ minor_tick_length minor_tick_width)
           end
 
           spec.update(@ticks_side)
+
+          # We don't allow Tioga to draw tick labels by itself
+          type = spec['type']
+          spec['type'] = case spec['type']
+                         when Tioga::FigureConstants::AXIS_WITH_MAJOR_TICKS_AND_NUMERIC_LABELS
+                           Tioga::FigureConstants::AXIS_WITH_MAJOR_TICKS_ONLY
+                         when Tioga::FigureConstants::AXIS_WITH_TICKS_AND_NUMERIC_LABELS
+                           Tioga::FigureConstants::AXIS_WITH_TICKS_ONLY
+                         else
+                           spec['type']
+                         end
           t.show_axis(spec)
+          # Now, we draw axis ticks
+          if type == Tioga::FigureConstants::AXIS_WITH_MAJOR_TICKS_AND_NUMERIC_LABELS || type == Tioga::FigureConstants::AXIS_WITH_TICKS_AND_NUMERIC_LABELS
+
+            fnc = info['vertical'] ? :convert_figure_to_frame_y : :convert_figure_to_frame_x
+            stl = @tick_label_style.dup
+            
+            
+            stl.shift ||= Types::Dimension.new(:dy, info['shift'])
+
+
+            # @todo integrate to the 
+            shift_def = ( 
+                         @location.base_location == :bottom ||
+                         @location.base_location == :at_y_origin ||
+                         @location.base_location == :right 
+                         ) ? 0.3 : 0.4
+            stl.shift = Types::Dimension.new(:dy, stl.shift.to_dy(t) + shift_def)
+
+            stl.valign ||= ( 
+                            @location.base_location == :bottom ||
+                            @location.base_location == :at_y_origin ||
+                            @location.base_location == :right 
+                            ) ? Tioga::FigureConstants::ALIGNED_AT_TOP : Tioga::FigureConstants::ALIGNED_AT_BOTTOM
+            
+            spec['labels'].size.times do |i|
+              pos = spec['major_ticks'][i]
+              label = spec['labels'][i]
+              pos = t.send(fnc, pos)
+              
+              next unless label
+
+
+              nm = "axis-tick#{@index}-#{i}"
+
+              stl.draw_text(t, label, spec['location'], 
+                            [:pos, pos], nm)
+              if watcher
+                watcher.watch(nm)
+              end
+            end
+          end
+
           @axis_label.loc = @location
           default = vertical? ? 'ylabel' : 'xlabel'
-          @axis_label.draw(t, default)
+          nm = "axis-label#{@index}"
+
+          # stl = @axis_label.dup
+          # # Default to aligning the label where it counts.
+          # stl.valign ||= ( 
+          #                 @location.base_location == :bottom ||
+          #                 @location.base_location == :at_y_origin ||
+          #                 @location.base_location == :right 
+          #                 ) ? Tioga::FigureConstants::ALIGNED_AT_MIDHEIGHT : Tioga::FigureConstants::ALIGNED_AT_BOTTOM
+
+          @axis_label.draw(t, default, nm)
+          if watcher
+            watcher.watch(nm)
+          end
         end
 
         # Sets the current boundaries of the _t_ object to the _range_
