@@ -76,6 +76,17 @@ module CTioga2
         # mode. A Dimension.
         attr_accessor :padding
 
+        # Mode for auto-adjust
+        attr_accessor :text_auto_adjust
+
+        # If not nil, then the boundaries are computed from the real
+        # dimensions of the plot frame, using the given number as a
+        # conversion factor from the output dimensions.
+        attr_accessor :frame_real_size
+
+
+        @@current_index = 0
+
         def initialize
           # Default style for the plots.
           @axes = {}
@@ -102,7 +113,6 @@ module CTioga2
             StyleSheet.style_for(TextLabel, 'title',
                                  nil, 
                                  Types::PlotLocation.new(:top))
-
           @plot_margin = nil
 
           @transforms = CoordinateTransforms.new
@@ -110,8 +120,20 @@ module CTioga2
           @background = 
             StyleSheet.style_for(BackgroundStyle, 'background')
 
-          # A padding of 4bp ? Why ?? Why not ?
-          @padding = Types::Dimension.new(:bp, 4)
+          # A padding of 6bp ? Why ?? Why not ?
+          @padding = Types::Dimension.new(:bp, 6)
+
+
+          
+          @text_size_index = @@current_index
+          @@current_index += 1
+
+          # Automatic adjustment of text sizes...
+          @text_sizes = TextSizeWatcher.new
+          @text_sizes.watch("title-#{@text_size_index}")
+
+          @text_auto_adjust = :both
+
         end
 
         # Apply (destructively) the current transformations to the
@@ -120,7 +142,6 @@ module CTioga2
           @transforms.transform_2d!(dataset)
         end
 
-
         # Whether to use log scale for the given axis.
         #
         # Now the question is: how should that affect user-defined
@@ -235,7 +256,7 @@ module CTioga2
             t.context do
               begin
                 axis.set_bounds_for_axis(t, bounds[which])
-                axis.draw_axis(t)
+                axis.draw_axis(t, @text_sizes)
               rescue Exception => e
                 error { "Impossible to draw axis #{which}: #{e.message}" }
                 debug { "Full message: #{e.inspect}\n#{e.backtrace.join("\n")}" }
@@ -243,7 +264,7 @@ module CTioga2
             end
           end
           # We draw the title last
-          title.draw(t, 'title')
+          title.draw(t, 'title', "title-#{@text_size_index}")
         end
 
         # Draws all axes background lines for the plot.
@@ -290,7 +311,7 @@ module CTioga2
               exts << @title.label_extension(t, 'title', @title.loc) * 
                 (@text_scale || 1)
             end
-            Types::Dimension.new(:dy, exts.max)
+            Types::Dimension.new(:dy, exts.max || 0)
           end
 
           box = Types::MarginsBox.new(*margins)
@@ -302,6 +323,40 @@ module CTioga2
           return box
         end
 
+        # Clear all axes
+        def clear_axes()
+          [:left, :right, :top, :bottom].each do |loc|
+            style = get_axis_style(loc)
+            style.decoration = Tioga::FigureConstants::AXIS_HIDDEN
+            style.axis_label.text = false
+          end
+        end
+
+        # Computes the margins based on the text information.
+        #
+        # This is very different from the one above, since this one
+        # relies on measured texts to get it right !
+        def compute_margins(t, prev_margins)
+          margins = estimate_margins(t)
+          if @text_auto_adjust == :old
+            return margins
+          else
+            pad = if @padding
+                    @padding.to_bp(t)
+                  else
+                    4
+                  end
+            nm =  @text_sizes.update_margins(t, prev_margins, pad)
+
+            # We include the old margins, unless we have the :measure
+            # text adjust mode
+            if @text_auto_adjust != :measure
+              nm.expand_to!(t, margins)
+            end
+            return nm
+          end
+        end
+
         protected
 
         # Takes a string and returns a Symbol suitable for use with
@@ -391,11 +446,7 @@ EOH
       ClearAxesCommand = 
           Cmd.new("clear-axes",nil,"--clear-axes"
                   ) do |plotmaker, opts|
-        [:left, :right, :top, :bottom].each do |loc|
-          style = AxisStyle.current_axis_style(plotmaker, loc)
-          style.decoration = Tioga::FigureConstants::AXIS_HIDDEN
-          style.axis_label.text = ""
-        end
+        PlotStyle.current_plot_style(plotmaker).clear_axes
       end
       ClearAxesCommand.
         describe("Clear all axes",
@@ -403,6 +454,33 @@ EOH
 Removes all the axes and their associated labels
 EOH
 
+      DrawingFrameCommand = 
+        Cmd.new("drawing-frame",nil,"--drawing-frame", [],
+                { 'units' => CmdArg.new('text') 
+                }) do |plotmaker, opts|
+        style = PlotStyle.current_plot_style(plotmaker)
+        style.clear_axes
+        style.padding = nil
+        u = opts['units'] || 'cm'
+        if u =~ /([\d.]+)?\s*(cm|in|bp|pt|mm)/
+          nb = $1 ? $1.to_f : 1.0
+          un = $2
+          style.frame_real_size = 10 * nb * 
+            Types::Dimension::DimensionConversion.fetch(un)
+        else
+          raise 'Invalid unit'
+        end
+      end
+      DrawingFrameCommand.
+        describe("Setup a drawing frame",
+                 <<"EOH", AxisGroup)
+Setup a drawing frame, ie a frame in which the top-left point is at
+0,0, with X and Y values positive over the whole frame, and counted in
+centimeters (or with the unit given using the @/units@ option, ie
+@/units=mm@ expressed in millimeters or @/units=12pt@ expressed in
+multiple of 12 TeX points).
+EOH
+
       
       TicksCommand = 
           Cmd.new("ticks",nil,"--ticks", 
