@@ -48,8 +48,22 @@ module CTioga2
         # @todo make it possible to provide a function to generate that ?
         typed_attribute :major, 'float-list'
 
+        # Separation between major ticks. Overriden by the major list
+        typed_attribute :major_delta, "float"
+
+        # Approximate number of major ticks
+        typed_attribute :major_number, "integer"
+
         # The list of the position of minor ticks
         typed_attribute :minor, 'float-list'
+
+        # Separation between minor ticks
+        typed_attribute :minor_delta, "float"
+
+        # Number of minor ticks between major ticks
+        typed_attribute :minor_number, "integer"
+
+
         
         # The list of labels
         typed_attribute :labels, 'text-list'
@@ -71,15 +85,35 @@ module CTioga2
           end
           fmt = @format
 
+          # beginning or end of the axis. Not specifically x
+          xl, xr = * (if info['vertical']
+                        [info['y0'], info['y1']]
+                      else
+                        [info['x0'], info['x1']]
+                      end)
+
+          if xl > xr
+            xl, xr = xr, xl
+          end
+
           if @major
             ret['minor_ticks'] = Dobjects::Dvector.new
             ret['major_ticks'] = Dobjects::Dvector.new(@major)
 
             fmt ||= "$%g$"
+          elsif @major_delta || @major_number
+            delta = @major_delta || Utils::closest_subdivision(( (xr - xl)/@major_number))
+            ret['major_ticks'] = Utils::integer_subdivisions(xl, xr, 
+                                                             delta)
+            fmt ||= "$%g$"
           end
 
           if @minor
             ret['minor_ticks'] = Dobjects::Dvector.new(@minor)
+          elsif @minor_delta || delta
+            dt = @minor_delta || delta/((@minor_number || 3)+1)
+            ret['minor_ticks'] = Utils::integer_subdivisions(xl, xr, 
+                                                             dt)
           end
 
           fmt_last = @format_last || fmt
