@@ -22,6 +22,13 @@ $ct -t 'See how to specify the second Y label' \
 # @todo this shows it is cumbersome to change all the colors in one go:
 # providing a --axis-color that just works would be great.
 
+$ct -t 'At origins' \
+    --axis-style left /location=x0 \
+    --top none --right none \
+    -x '$x$ values' '2*sin(x)+1' -y '$y$ values' \
+
+
+
 # See how the meaning of y and yaxis is dependent on the default axis.
 $ct -t 'With different colors for the axes' \
     -x '$x$ values' 'sin(x)' -y '$y_1$ values' /color Red \
@@ -37,6 +44,12 @@ $ct -t 'Tweaking the aspect of labels ' \
     -y '$y$ values' /shift=5mm /scale=5mm \
     --label-style x /scale=7mm 
 
+# Multiline labels
+$ct -t 'A very long title about quite uninteresting things ' \
+    /text-width=6cm /alignment=bottom -r 8cmx12cm \
+    -x 'A long label for the $x$ axis demonstrating auto width' /text-width=auto  'sin(x)' \
+    -y 'An even longer label for the $y$ axis in order to demonstrate that the auto width works also vertically' /text-width=auto /valign=bottom
+
 
 # # Alternative axes
 # $ct 'sin(x)' --x2 --y2 'x**2' --yrange -20:50 'cos(x)' /yaxis left \
