@@ -13,7 +13,11 @@ $ct -t 'Text drawing' -r 10cmx10cm \
     --draw-line 0,-1 0,1 /color Blue /style Dashes \
     --draw-text 0,-0.3 'left plus bottom' /justification left \
     /color Orange /scale 1.2  /alignment bottom \
-    --draw-line -6,-0.3 6,-0.3 /color Green /style Dots 
+    --draw-line -6,-0.3 6,-0.3 /color Green /style Dots \
+    --draw-text 0,0.6 'right top (h/v)' /halign right \
+    /color Orange /scale 1.2  /valign top \
+    --draw-line -6,0.6 6,0.6 /color Green /style Dots 
+
 
 
 
@@ -52,3 +56,24 @@ $ct -t 'Styled markers' -r 10cmx10cm --math-xrange -3:3 \
     /vertical_scale=0.5 /color=Green \
     --draw-string-marker '0,-0.2' TriangleUp /base-style=marker-string \
     /horizontal_scale=1 /color=Blue
+
+# Now, we need to create a PNG and a JPEG file
+
+echo "Creating necessary JPEG and PNG files"
+convert -size 320x85 xc:white -pointsize 72 -fill Red -draw "text 25,60 'JPEG'" t1.jpeg
+convert -size 320x85 xc:white -pointsize 72 -fill Red -draw "text 25,60 'PNG'" -stroke black -draw 'rectangle 230,10 280,60' t1.png
+
+$ct --drawing-frame /units=1cm \
+    -t 'PNG and JPEG images' -r 10cmx10cm \
+    --draw-image t1.jpeg 1,1 3,3 \
+    --draw-image t1.png 1,4 3,6 \
+    --draw-image t1.png 4,4 6,6 /aspect-ratio=contract  \
+    --draw-image t1.png 4,7 6,9 /aspect-ratio=expand \
+    --draw-image t1.jpeg 1.5,1.5 3.5,3.5 /transparency=0.5
+
+
+$ct -t 'Tangents: a direction, and a proper arrow' -r 10cmx10cm \
+    'sin(x)' \
+    --draw-tangent 0.5  \
+    --draw-tangent 0.6 /xto=5 /color=Black /line-style=Dashes /nbavg=3\
+    --draw-tangent 0.3 /xextent=1 /color=Pink /style=Dots /nbavg=3
