@@ -43,3 +43,20 @@ $ct -t 'Legend frames, take 2' -r 10cmx10cm \
     -l '$x^2$' 'x**2' \
     -l '$5 x$' '5 * x' \
     --legend-line 'More padding !'
+
+$ct -t 'Tiled legends inside' -r 10cmx10cm \
+    --legend-inside tc /scale 2 /dy=1.02 \
+    --legend-line 'Line outside of tiles' \
+    --legend-multicol /dx=12mm \
+    -l '$x^2$' 'x**2' \
+    -l '$2 x$' '2 * x' \
+    -l '$3 x$' '3 * x' \
+    -l '$5 x$' '5 * x' 
+
+$ct -t 'Large legends' -r 10cmx10cm \
+    --legend-inside cc /scale 2 /vpadding=2mm /frame_color=Black \
+    /frame_fill_color='White' /frame_fill_transparency=0.2 \
+    /frame_width=0.5 \
+    -l '\LARGE $\displaystyle 2 \times \int_0^x x'\'' \mathrm{d} x'\''$' 'x**2' \
+    -l '$5 x$' '5 * x' \
+    -l '$2 x$' '2 * x'
